package com.dayou.controller;

import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RestController;
import com.dayou.controller.BaseController;
import com.dayou.service.IProductionReturnService;
import com.dayou.entity.ProductionReturn;
import com.dayou.common.RestResponse;
import org.springframework.web.bind.annotation.*;
import com.dayou.common.PullDownModel;
import com.dayou.utils.ConvertUtil;
import com.dayou.utils.HttpKit;
import com.dayou.exception.ErrorCode;
import java.util.Date;
import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.http.MediaType;
import org.springframework.web.multipart.MultipartFile;
/**
 * 产品退回申请表
 *
 * @author GouGengquan
 * @since 2025-04-07
 */
@RestController
@RequestMapping("productionReturn")
@Slf4j
public class ProductionReturnController extends BaseController {
    @Autowired
    private IProductionReturnService productionReturnService;

    /**
    * 产品退回申请表列表
    */
    @GetMapping("")
    public RestResponse<Page<ProductionReturn>> page(ProductionReturn productionReturn, Page page){
        Page<ProductionReturn> pages=productionReturnService.selectPage(page,productionReturn);
        return RestResponse.data(pages);
    }

    /**
     * 产品退回申请表详情
     */
    @GetMapping("/{id}")
    public RestResponse<ProductionReturn> detail(@PathVariable Long id){
        ProductionReturn xProductionReturn =productionReturnService.detail(id);
        return RestResponse.data(xProductionReturn);
     }

    /**
     * 产品退回申请表新增
     */
    @PostMapping("")
    public RestResponse<Boolean> save(@RequestBody ProductionReturn productionReturn) {
        Boolean ret = productionReturnService.add(productionReturn);
        return RestResponse.data(ret);
    }

    /**
     * 产品退回申请表更新
     */
    @PutMapping("")
    public RestResponse<Boolean> update(@RequestBody ProductionReturn productionReturn) {
        Boolean ret = productionReturnService.update(productionReturn);
        return RestResponse.data(ret);
    }

    /**
     * 产品退回申请表删除
     */
    @DeleteMapping("/{id}")
    public RestResponse<Boolean> delete(@PathVariable Long id) {
        Boolean ret = productionReturnService.delete(id);
        return RestResponse.data(ret);
    }


    /**
     * 产品退回申请表下拉列表
     */
    @GetMapping("/simpleAll")
    public RestResponse<List<PullDownModel>> simpleAll(){
        LambdaQueryWrapper<ProductionReturn> lambdaQueryWrapper = new LambdaQueryWrapper<ProductionReturn>()
        .select(ProductionReturn::getId,ProductionReturn::getName)
        .eq(ProductionReturn::getDeleted,false);
        List<ProductionReturn> list= productionReturnService.list(lambdaQueryWrapper);
        List<PullDownModel> ret=ConvertUtil.copyList(list, PullDownModel.class);
        return RestResponse.data(ret);
    }
}

